| /netbsd-src/external/apache2/llvm/dist/llvm/include/llvm/Support/ |
| H A D | DebugCounter.h | 78 auto &Us = instance(); in shouldExecute() local 79 auto Result = Us.Counters.find(CounterName); in shouldExecute() 80 if (Result != Us.Counters.end()) { in shouldExecute() 108 auto &Us = instance(); in getCounterValue() local 109 auto Result = Us.Counters.find(ID); in getCounterValue() 110 assert(Result != Us.Counters.end() && "Asking about a non-set counter"); in getCounterValue() 116 auto &Us = instance(); in setCounterValue() local 117 Us.Counters[ID].Count = Count; in setCounterValue()
|
| /netbsd-src/external/apache2/llvm/dist/llvm/lib/IR/ |
| H A D | User.cpp | 117 void *User::allocateFixedOperandUser(size_t Size, unsigned Us, in allocateFixedOperandUser() argument 119 assert(Us < (1u << NumUserOperandsBits) && "Too many operands"); in allocateFixedOperandUser() 129 ::operator new(Size + sizeof(Use) * Us + DescBytesToAllocate)); in allocateFixedOperandUser() 131 Use *End = Start + Us; in allocateFixedOperandUser() 133 Obj->NumUserOperands = Us; in allocateFixedOperandUser() 147 void *User::operator new(size_t Size, unsigned Us) { in operator new() argument 148 return allocateFixedOperandUser(Size, Us, 0); in operator new() 151 void *User::operator new(size_t Size, unsigned Us, unsigned DescBytes) { in operator new() argument 152 return allocateFixedOperandUser(Size, Us, DescBytes); in operator new()
|
| /netbsd-src/external/apache2/llvm/dist/llvm/lib/Target/Hexagon/ |
| H A D | HexagonCommonGEP.cpp | 282 const UseSet &Us = I->second; in operator <<() local 283 OS << I->first << " -> #" << Us.size() << '{'; in operator <<() 284 for (UseSet::const_iterator J = Us.begin(), F = Us.end(); J != F; ++J) { in operator <<() 355 UseSet Us; in processGepInst() local 365 Us.insert(&UI.getUse()); in processGepInst() 390 if (!Us.empty()) { in processGepInst() 392 Uses[PN].insert(Us.begin(), Us.end()); in processGepInst() 763 UseSet &Us = UF->second; in recalculatePlacement() local 764 for (UseSet::iterator I = Us.begin(), E = Us.end(); I != E; ++I) { in recalculatePlacement() 972 UseSet &Us = UF->second; in separateChainForNode() local [all …]
|
| H A D | HexagonGenInsert.cpp | 1346 RegisterSet Us; in selectCandidates() local 1348 getInstrUses(DefI, Us); in selectCandidates() 1353 for (unsigned R = Us.find_first(); R; R = Us.find_next(R)) { in selectCandidates() 1362 for (unsigned R = Us.find_first(); R; R = Us.find_next(R)) { in selectCandidates()
|
| /netbsd-src/external/apache2/llvm/dist/llvm/lib/Support/ |
| H A D | DebugCounter.cpp | 123 auto &Us = instance(); in print() local 128 << Us.Counters[CounterID].Count << "," << Us.Counters[CounterID].Skip in print() 129 << "," << Us.Counters[CounterID].StopAfter << "}\n"; in print()
|
| /netbsd-src/external/apache2/llvm/dist/llvm/include/llvm/ADT/ |
| H A D | PointerUnion.h | 70 template <typename T, typename ...Us> struct TypeIndex; 71 template <typename T, typename ...Us> struct TypeIndex<T, T, Us...> { 74 template <typename T, typename U, typename... Us> 75 struct TypeIndex<T, U, Us...> { 76 static constexpr int Index = 1 + TypeIndex<T, Us...>::Index;
|
| /netbsd-src/external/apache2/llvm/dist/clang/include/clang/Basic/ |
| H A D | BuiltinsHexagon.def | 57 TARGET_BUILTIN(__builtin_brev_lduh, "v*Us*CUs*iC", "", V5) 63 TARGET_BUILTIN(__builtin_circ_lduh, "Us*Us*Us*iIi", "", V5)
|
| H A D | BuiltinsAMDGPU.def | 36 BUILTIN(__builtin_amdgcn_workgroup_size_x, "Us", "nc") 37 BUILTIN(__builtin_amdgcn_workgroup_size_y, "Us", "nc") 38 BUILTIN(__builtin_amdgcn_workgroup_size_z, "Us", "nc")
|
| /netbsd-src/crypto/external/bsd/openssl/dist/apps/ |
| H A D | dsa1024.pem | 3 mUd6UvuF5NmmezibaIqEm4fGHrV+hktTW1nPcWUZiG7OZq5riDb77Cjcwtelu+Us
|
| /netbsd-src/crypto/external/bsd/openssl.old/dist/apps/ |
| H A D | dsa1024.pem | 3 mUd6UvuF5NmmezibaIqEm4fGHrV+hktTW1nPcWUZiG7OZq5riDb77Cjcwtelu+Us
|
| /netbsd-src/external/apache2/llvm/dist/llvm/include/llvm/IR/ |
| H A D | User.h | 61 void *operator new(size_t Size, unsigned Us); 71 void *operator new(size_t Size, unsigned Us, unsigned DescBytes);
|
| /netbsd-src/sys/external/bsd/compiler_rt/dist/lib/xray/ |
| H A D | xray_allocator.h | 140 T *initArray(size_t N, U &&... Us) XRAY_NEVER_INSTRUMENT { in initArray() argument 144 new (A + (--N)) T(std::forward<U>(Us)...); in initArray()
|
| /netbsd-src/external/bsd/less/dist/lesstest/lt/ |
| H A D | subsearch.lt | 3041 …with the characteristics of the terminal._______________________________ * Us@04es@00 termcap to b… 3043 …with the characteristics of the terminal._______________________________ * Us@04es@00 termcap to b… 3045 …with the characteristics of the terminal._______________________________ * Us@04es@00 termcap to b… 3047 …with the characteristics of the terminal._______________________________ * Us@04es@00 termcap to b… 3049 …with the characteristics of the terminal._______________________________ * Us@04es@00 termcap to b… 3051 …with the characteristics of the terminal._______________________________ * Us@04es@00 termcap to b… 3053 …with the characteristics of the terminal._______________________________ * Us@04es@00 termcap to b… 3055 …with the characteristics of the terminal._______________________________ * Us@04es@00 termcap to b… 3057 …with the characteristics of the terminal._______________________________ * Us@04es@00 termcap to b… 3059 …with the characteristics of the terminal._______________________________ * Us@04es@00 termcap to b… [all …]
|
| /netbsd-src/external/gpl3/gcc.old/dist/gcc/config/csky/ |
| H A D | constraints.md | 171 (define_constraint "Us"
|
| /netbsd-src/external/gpl3/gcc/dist/gcc/config/csky/ |
| H A D | constraints.md | 177 (define_constraint "Us"
|
| /netbsd-src/external/gpl3/gcc.old/dist/gcc/config/arm/ |
| H A D | mve.md | 7513 (unspec:MVE_2 [(match_operand:<MVE_B_ELEM> 1 "memory_operand" "Us") 7653 (unspec:MVE_2 [(match_operand:<MVE_B_ELEM> 1 "memory_operand" "Us") 7741 (unspec:MVE_6 [(match_operand:<MVE_H_ELEM> 1 "memory_operand" "Us") 7764 (unspec:MVE_6 [(match_operand:<MVE_H_ELEM> 1 "memory_operand" "Us") 7789 (unspec:MVE_6 [(match_operand:<MVE_H_ELEM> 1 "memory_operand" "Us") 7812 (unspec:MVE_6 [(match_operand:<MVE_H_ELEM> 1 "memory_operand" "Us") 8041 (unspec:V2DI [(match_operand:V2DI 1 "memory_operand" "Us") 8061 (unspec:V2DI [(match_operand:V2DI 1 "memory_operand" "Us") 8082 (unspec:V2DI [(match_operand:V2DI 1 "memory_operand" "Us") 8102 (unspec:V2DI [(match_operand:V2DI 1 "memory_operand" "Us") [all …]
|
| H A D | constraints.md | 42 ;; in ARM/Thumb-2 state: Uh, Ut, Uv, Uy, Un, Um, Us, Up, Uf, Ux, Ul 485 (define_memory_constraint "Us"
|
| /netbsd-src/external/gpl3/gcc/dist/gcc/config/arm/ |
| H A D | mve.md | 7157 (unspec:MVE_2 [(match_operand:<MVE_B_ELEM> 1 "memory_operand" "Us") 7295 (unspec:MVE_2 [(match_operand:<MVE_B_ELEM> 1 "memory_operand" "Us") 7383 (unspec:MVE_6 [(match_operand:<MVE_H_ELEM> 1 "memory_operand" "Us") 7406 (unspec:MVE_6 [(match_operand:<MVE_H_ELEM> 1 "memory_operand" "Us") 7431 (unspec:MVE_6 [(match_operand:<MVE_H_ELEM> 1 "memory_operand" "Us") 7454 (unspec:MVE_6 [(match_operand:<MVE_H_ELEM> 1 "memory_operand" "Us") 7683 (unspec:V2DI [(match_operand:V2DI 1 "memory_operand" "Us") 7703 (unspec:V2DI [(match_operand:V2DI 1 "memory_operand" "Us") 7724 (unspec:V2DI [(match_operand:V2DI 1 "memory_operand" "Us") 7744 (unspec:V2DI [(match_operand:V2DI 1 "memory_operand" "Us") [all …]
|
| H A D | constraints.md | 42 ;; in ARM/Thumb-2 state: Uh, Ut, Uv, Uy, Un, Um, Us, Up, Uf, Ux, Ul 500 (define_memory_constraint "Us"
|
| /netbsd-src/external/gpl3/gcc/dist/gcc/config/arc/ |
| H A D | constraints.md | 361 (define_constraint "Us<" 369 (define_constraint "Us>"
|
| /netbsd-src/external/gpl3/gcc.old/dist/gcc/config/arc/ |
| H A D | constraints.md | 361 (define_constraint "Us<" 369 (define_constraint "Us>"
|
| /netbsd-src/external/apache2/llvm/dist/llvm/include/llvm/ExecutionEngine/Orc/Shared/ |
| H A D | RPCUtils.h | 861 typename U, typename... Us> 862 class RPCArgTypeCheckHelper<P, std::tuple<T, Ts...>, std::tuple<U, Us...>> { 866 RPCArgTypeCheckHelper<P, std::tuple<Ts...>, std::tuple<Us...>>::value;
|
| /netbsd-src/external/apache2/llvm/dist/llvm/lib/Target/ARM/ |
| H A D | ARMTargetTransformInfo.cpp | 1533 const User *Us = *I->users().begin(); in getGatherScatterOpCost() local 1534 if (isa<ZExtInst>(Us) || isa<SExtInst>(Us)) { in getGatherScatterOpCost() 1537 cast<Instruction>(Us)->getType()->getScalarSizeInBits(); in getGatherScatterOpCost()
|
| /netbsd-src/games/quiz/datfiles/ |
| H A D | poetry | 83 {The }World is Too Much With Us|Sonnet:\
|
| /netbsd-src/external/apache2/llvm/dist/llvm/lib/Analysis/ |
| H A D | MemoryDependenceAnalysis.cpp | 321 for (const Use &Us : Ptr->uses()) { in getInvariantGroupPointerDependency() local 322 auto *U = dyn_cast<Instruction>(Us.getUser()); in getInvariantGroupPointerDependency()
|